@@ -3,13 +3,13 @@ package net.bytebuddy.dynamic.loading;
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 import lombok.EqualsAndHashCode;
 import net.bytebuddy.ByteBuddy;
-import net.bytebuddy.ClassFileVersion;
 import net.bytebuddy.description.modifier.Visibility;
 import net.bytebuddy.description.type.TypeDescription;
 import net.bytebuddy.dynamic.DynamicType;
 import net.bytebuddy.dynamic.scaffold.subclass.ConstructorStrategy;
 import net.bytebuddy.implementation.FixedValue;
 import net.bytebuddy.implementation.MethodCall;
+import net.bytebuddy.utility.JavaModule;
 import net.bytebuddy.utility.JavaType;
 import net.bytebuddy.utility.RandomString;
 import org.objectweb.asm.Opcodes;
@@ -279,7 +279,7 @@ public interface ClassInjector {
                 /**
                  * Initializes this dispatcher.
                  *
-                 * @return The initiailized dispatcher.
+                 * @return The initialized dispatcher.
                  */
                 Dispatcher initialize();
             }
@@ -290,7 +290,7 @@ public interface ClassInjector {
             enum CreationAction implements PrivilegedAction<Initializable> {
 
                 /**
-                 * The singelton instance.
+                 * The singleton instance.
                  */
                 INSTANCE;
 
@@ -298,7 +298,7 @@ public interface ClassInjector {
                 @SuppressFBWarnings(value = "REC_CATCH_EXCEPTION", justification = "Exception should not be rethrown but trigger a fallback")
                 public Initializable run() {
                     try {
-                        return ClassFileVersion.ofThisVm().isAtLeast(ClassFileVersion.JAVA_V9)
+                        return JavaModule.isSupported()
                                 ? Dispatcher.Indirect.make()
                                 : Dispatcher.Direct.make();
                     } catch (Exception exception) {
@@ -894,6 +894,15 @@ public interface ClassInjector {
             return new UsingLookup(DISPATCHER.dropLookupMode(lookup, Opcodes.ACC_PRIVATE));
         }
 
+        /**
+         * Checks if the current VM is capable of defining classes using a method handle lookup.
+         *
+         * @return {@code true} if the current VM is capable of defining classes using a lookup.
+         */
+        public static boolean isAvailable() {
+            return DISPATCHER.isAlive();
+        }
+
         /**
          * Returns the lookup type this injector is based upon.
          *
@@ -908,7 +917,7 @@ public interface ClassInjector {
             Map<TypeDescription, Class<?>> loaded = new HashMap<TypeDescription, Class<?>>();
             for (Map.Entry<? extends TypeDescription, byte[]> entry : types.entrySet()) {
                 if (!entry.getKey().isSamePackage(new TypeDescription.ForLoadedType(lookupType()))) {
-                    throw new IllegalArgumentException(entry.getKey() + " cannot be defined in its package using " + lookup);
+                    throw new IllegalArgumentException(entry.getKey() + " must be defined in the same package as " + lookup);
                 }
                 loaded.put(entry.getKey(), DISPATCHER.defineClass(lookup, entry.getValue()));
             }
@@ -1368,9 +1377,9 @@ public interface ClassInjector {
     class UsingInstrumentation implements ClassInjector {
 
         /**
-         * A prefix to use of generated files.
+         * The jar file name extension.
          */
-        private static final String PREFIX = "jar";
+        private static final String JAR = "jar";
 
         /**
          * The class file extension.
@@ -1429,7 +1438,7 @@ public interface ClassInjector {
 
         @Override
         public Map<TypeDescription, Class<?>> inject(Map<? extends TypeDescription, byte[]> types) {
-            File jarFile = new File(folder, String.format("%s%s.jar", PREFIX, randomString.nextString()));
+            File jarFile = new File(folder, JAR + randomString.nextString() + "." + JAR);
             try {
                 if (!jarFile.createNewFile()) {
                     throw new IllegalStateException("Cannot create file " + jarFile);
