@@ -476,8 +476,8 @@ public class MethodCall implements Implementation.Composable {
      */
     public MethodCall withField(FieldLocator.Factory fieldLocatorFactory, String... name) {
         List<ArgumentLoader.Factory> argumentLoaders = new ArrayList<ArgumentLoader.Factory>(name.length);
-        for (String aFieldName : name) {
-            argumentLoaders.add(new ArgumentLoader.ForField.Factory(aFieldName, fieldLocatorFactory));
+        for (String aName : name) {
+            argumentLoaders.add(new ArgumentLoader.ForField.Factory(aName, fieldLocatorFactory));
         }
         return with(argumentLoaders);
     }
@@ -1199,7 +1199,7 @@ public class MethodCall implements Implementation.Composable {
                  */
                 public Factory(Object value) {
                     this.value = value;
-                    name = String.format("%s$%s", FIELD_PREFIX, RandomString.make());
+                    name = FIELD_PREFIX + "$" + RandomString.make();
                 }
 
                 @Override
@@ -1440,7 +1440,11 @@ public class MethodCall implements Implementation.Composable {
             INSTANCE;
 
             @Override
-            public StackManipulation resolve(MethodDescription invokedMethod, MethodDescription instrumentedMethod, TypeDescription instrumentedType, Assigner assigner, Assigner.Typing typing) {
+            public StackManipulation resolve(MethodDescription invokedMethod,
+                                             MethodDescription instrumentedMethod,
+                                             TypeDescription instrumentedType,
+                                             Assigner assigner,
+                                             Assigner.Typing typing) {
                 return new StackManipulation.Compound(
                         invokedMethod.isStatic()
                                 ? StackManipulation.Trivial.INSTANCE
@@ -1468,7 +1472,11 @@ public class MethodCall implements Implementation.Composable {
             INSTANCE;
 
             @Override
-            public StackManipulation resolve(MethodDescription invokedMethod, MethodDescription instrumentedMethod, TypeDescription instrumentedType, Assigner assigner, Assigner.Typing typing) {
+            public StackManipulation resolve(MethodDescription invokedMethod,
+                                             MethodDescription instrumentedMethod,
+                                             TypeDescription instrumentedType,
+                                             Assigner assigner,
+                                             Assigner.Typing typing) {
                 return new StackManipulation.Compound(TypeCreation.of(invokedMethod.getDeclaringType().asErasure()), Duplication.SINGLE);
             }
 
@@ -1513,7 +1521,7 @@ public class MethodCall implements Implementation.Composable {
             protected ForValue(Object target, TypeDescription.Generic fieldType) {
                 this.target = target;
                 this.fieldType = fieldType;
-                name = String.format("%s$%s", FIELD_PREFIX, RandomString.make());
+                name = FIELD_PREFIX + "$" + RandomString.make();
             }
 
             @Override
@@ -1535,7 +1543,9 @@ public class MethodCall implements Implementation.Composable {
             @Override
             public InstrumentedType prepare(InstrumentedType instrumentedType) {
                 return instrumentedType
-                        .withField(new FieldDescription.Token(name, Opcodes.ACC_SYNTHETIC | Opcodes.ACC_PUBLIC | Opcodes.ACC_STATIC, fieldType))
+                        .withField(new FieldDescription.Token(name,
+                                Opcodes.ACC_PUBLIC | Opcodes.ACC_STATIC | Opcodes.ACC_VOLATILE | Opcodes.ACC_SYNTHETIC,
+                                fieldType))
                         .withInitializer(new LoadedTypeInitializer.ForStaticField(name, target));
             }
         }
@@ -1575,6 +1585,10 @@ public class MethodCall implements Implementation.Composable {
                     throw new IllegalStateException("Could not locate field name " + name + " on " + instrumentedType);
                 } else if (!resolution.getField().isStatic() && !instrumentedType.isAssignableTo(resolution.getField().getDeclaringType().asErasure())) {
                     throw new IllegalStateException("Cannot access " + resolution.getField() + " from " + instrumentedType);
+                } else if (!invokedMethod.isInvokableOn(resolution.getField().getType().asErasure())) {
+                    throw new IllegalStateException("Cannot invoke " + invokedMethod + " on " + resolution.getField());
+                } else if (!invokedMethod.isAccessibleTo(instrumentedType)) {
+                    throw new IllegalStateException("Cannot access " + invokedMethod + " from " + instrumentedType);
                 }
                 StackManipulation stackManipulation = assigner.assign(resolution.getField().getType(), invokedMethod.getDeclaringType().asGenericType(), typing);
                 if (!stackManipulation.isValid()) {
@@ -1665,8 +1679,6 @@ public class MethodCall implements Implementation.Composable {
             public StackManipulation invoke(MethodDescription invokedMethod, Target implementationTarget) {
                 if (invokedMethod.isVirtual() && !invokedMethod.isInvokableOn(implementationTarget.getInstrumentedType())) {
                     throw new IllegalStateException("Cannot invoke " + invokedMethod + " on " + implementationTarget.getInstrumentedType());
-                } else if (!invokedMethod.isVisibleTo(implementationTarget.getInstrumentedType())) {
-                    throw new IllegalStateException(invokedMethod + " is not visible to " + implementationTarget.getInstrumentedType());
                 }
                 return invokedMethod.isVirtual()
                         ? MethodInvocation.invoke(invokedMethod).virtual(implementationTarget.getInstrumentedType())
@@ -1890,7 +1902,7 @@ public class MethodCall implements Implementation.Composable {
          * Invokes the specified method on the instrumented method's argument of the given index.
          *
          * @param index The index of the method's argument on which the specified method should be invoked.
-         * @return Amethod call that invokes the provided method on the given method argument.
+         * @return A method call that invokes the provided method on the given method argument.
          */
         public MethodCall onArgument(int index) {
             if (index < 0) {
@@ -1988,6 +2000,9 @@ public class MethodCall implements Implementation.Composable {
         @Override
         public Size apply(MethodVisitor methodVisitor, Context implementationContext, MethodDescription instrumentedMethod) {
             MethodDescription invokedMethod = methodLocator.resolve(implementationTarget.getInstrumentedType(), instrumentedMethod);
+            if (!invokedMethod.isVisibleTo(implementationTarget.getInstrumentedType())) {
+                throw new IllegalStateException("Cannot invoke " + invokedMethod + " from " + implementationContext.getInstrumentedType());
+            }
             List<ArgumentLoader> argumentLoaders = new ArrayList<ArgumentLoader>(MethodCall.this.argumentLoaders.size());
             for (ArgumentLoader.Factory argumentLoader : MethodCall.this.argumentLoaders) {
                 argumentLoaders.addAll(argumentLoader.make(implementationTarget.getInstrumentedType(), instrumentedMethod, invokedMethod));
