@@ -44,14 +44,14 @@ public abstract class AbstractMethodDescriptionTest {
     protected Constructor<?> firstConstructor, secondConstructor;
 
     private static int hashCode(Method method) {
-        int hashCode = new TypeDescription.ForLoadedType(method.getDeclaringClass()).hashCode();
+        int hashCode = 17 + new TypeDescription.ForLoadedType(method.getDeclaringClass()).hashCode();
         hashCode = 31 * hashCode + method.getName().hashCode();
         hashCode = 31 * hashCode + new TypeDescription.ForLoadedType(method.getReturnType()).hashCode();
         return 31 * hashCode + new TypeList.ForLoadedTypes(method.getParameterTypes()).hashCode();
     }
 
     private static int hashCode(Constructor<?> constructor) {
-        int hashCode = new TypeDescription.ForLoadedType(constructor.getDeclaringClass()).hashCode();
+        int hashCode = 17 + new TypeDescription.ForLoadedType(constructor.getDeclaringClass()).hashCode();
         hashCode = 31 * hashCode + MethodDescription.CONSTRUCTOR_INTERNAL_NAME.hashCode();
         hashCode = 31 * hashCode + TypeDescription.VOID.hashCode();
         return 31 * hashCode + new TypeList.ForLoadedTypes(constructor.getParameterTypes()).hashCode();
@@ -756,6 +756,17 @@ public abstract class AbstractMethodDescriptionTest {
                 Arrays.asList(new TypeDescription.ForLoadedType(String.class), new TypeDescription.ForLoadedType(int.class)))), is(false));
     }
 
+    @Test
+    public void testSyntethicParameter() throws Exception {
+        Constructor<?> constructor = null;
+        for (Constructor<?> candidate : SyntheticParameter.class.getDeclaredConstructors()) {
+            if (candidate.getParameterTypes().length == 2) {
+                constructor = candidate;
+            }
+        }
+        assertThat(describe(constructor).getParameters().get(1).getDeclaredAnnotations().isAnnotationPresent(Deprecated.class), is(true));
+    }
+
     @Test
     @SuppressWarnings("unchecked")
     public void testIsDefault() throws Exception {
@@ -992,4 +1003,10 @@ public abstract class AbstractMethodDescriptionTest {
 
         SampleEnumeration[] enum_property_array();
     }
+
+    public class SyntheticParameter {
+
+        public SyntheticParameter(@Deprecated Void unused) {
+        }
+    }
 }
