@@ -133,6 +133,23 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
         assertThat(describe(long[].class).getStackSize(), is(StackSize.SINGLE));
     }
 
+    @Test
+    public void testDefaultValue() throws Exception {
+        assertThat(describe(void.class).getDefaultValue(), nullValue(Object.class));
+        assertThat(describe(boolean.class).getDefaultValue(), is((Object) false));
+        assertThat(describe(byte.class).getDefaultValue(), is((Object) (byte) 0));
+        assertThat(describe(short.class).getDefaultValue(), is((Object) (short) 0));
+        assertThat(describe(char.class).getDefaultValue(), is((Object) (char) 0));
+        assertThat(describe(int.class).getDefaultValue(), is((Object) 0));
+        assertThat(describe(long.class).getDefaultValue(), is((Object) 0L));
+        assertThat(describe(float.class).getDefaultValue(), is((Object) 0f));
+        assertThat(describe(double.class).getDefaultValue(), is((Object) 0d));
+        assertThat(describe(Object.class).getDefaultValue(), nullValue(Object.class));
+        assertThat(describe(SampleClass.class).getDefaultValue(), nullValue(Object.class));
+        assertThat(describe(Object[].class).getDefaultValue(), nullValue(Object.class));
+        assertThat(describe(long[].class).getDefaultValue(), nullValue(Object.class));
+    }
+
     @Test
     public void testName() throws Exception {
         for (Class<?> type : standardTypes) {
@@ -603,11 +620,11 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
 
     @Test
     public void testGetSegmentCount() throws Exception {
-        assertThat(describe(GenericSample.class).getSegmentCount(), is(0));
-        assertThat(describe(GenericSample.Inner.class).getSegmentCount(), is(1));
-        assertThat(describe(GenericSample.Nested.class).getSegmentCount(), is(0));
-        assertThat(describe(GenericSample.NestedInterface.class).getSegmentCount(), is(0));
-        assertThat(describe(Object.class).getSegmentCount(), is(0));
+        assertThat(describe(GenericSample.class).getInnerClassCount(), is(0));
+        assertThat(describe(GenericSample.Inner.class).getInnerClassCount(), is(1));
+        assertThat(describe(GenericSample.Nested.class).getInnerClassCount(), is(0));
+        assertThat(describe(GenericSample.NestedInterface.class).getInnerClassCount(), is(0));
+        assertThat(describe(Object.class).getInnerClassCount(), is(0));
     }
 
     @Test
